@@ -120,8 +120,10 @@ struct
   int s2k_mode;
   int s2k_digest_algo;
   int s2k_cipher_algo;
-  int simple_sk_checksum; /* create the deprecated rfc2440 secret
-			     key protection*/
+  unsigned char s2k_count; /* This is the encoded form, not the raw
+			      count */
+  int simple_sk_checksum; /* create the deprecated rfc2440 secret key
+			     protection */
   int not_dash_escaped;
   int escape_from;
   int lock_once;
@@ -237,7 +239,7 @@ struct
 
   /* True if multiple concatenated signatures may be verified. */
   int allow_multisig_verification; 
-
+  int passwd_repeat;
 } opt;
 
 /* CTRL is used to keep some global variables we currently can't
